# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,omophub_concepts)
S3method(as.data.frame,omophub_hierarchy)
S3method(as.data.frame,omophub_mappings)
S3method(as.data.frame,omophub_relationships)
S3method(as.data.frame,omophub_vocabularies)
S3method(print,omophub_concepts)
S3method(print,omophub_hierarchy)
S3method(print,omophub_mappings)
S3method(print,omophub_relationships)
S3method(print,omophub_vocabularies)
export(OMOPHubClient)
export(fhir_resolve)
export(fhir_resolve_batch)
export(fhir_resolve_codeable_concept)
export(get_api_key)
export(has_api_key)
export(omophub_fhir_url)
export(set_api_key)
importFrom(R6,R6Class)
importFrom(cli,cli_abort)
importFrom(cli,cli_inform)
importFrom(cli,cli_warn)
importFrom(glue,glue)
importFrom(httr2,req_body_json)
importFrom(httr2,req_error)
importFrom(httr2,req_headers)
importFrom(httr2,req_perform)
importFrom(httr2,req_retry)
importFrom(httr2,req_throttle)
importFrom(httr2,req_timeout)
importFrom(httr2,req_url_path_append)
importFrom(httr2,req_url_query)
importFrom(httr2,req_user_agent)
importFrom(httr2,request)
importFrom(httr2,resp_body_json)
importFrom(httr2,resp_status)
importFrom(purrr,map)
importFrom(purrr,map_chr)
importFrom(purrr,map_dbl)
importFrom(purrr,map_int)
importFrom(purrr,map_lgl)
importFrom(rlang,abort)
importFrom(rlang,caller_env)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
