% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/zzz.R
\name{.onAttach}
\alias{.onAttach}
\title{Package Attach Hook}
\usage{
.onAttach(libname, pkgname)
}
\arguments{
\item{libname}{Library name.}

\item{pkgname}{Package name.}
}
\description{
Package Attach Hook
}
\keyword{internal}
