% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/auth.R
\name{has_api_key}
\alias{has_api_key}
\title{Check if API Key is Available}
\usage{
has_api_key()
}
\value{
\code{TRUE} if an API key is available, \code{FALSE} otherwise.
}
\description{
Checks whether an OMOPHub API key is available without throwing an error.
}
