% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/zzz.R
\name{.onLoad}
\alias{.onLoad}
\title{Package Load Hook}
\usage{
.onLoad(libname, pkgname)
}
\arguments{
\item{libname}{Library name.}

\item{pkgname}{Package name.}
}
\description{
Package Load Hook
}
\keyword{internal}
