% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/response.R
\name{new_omophub_concepts}
\alias{new_omophub_concepts}
\title{Create OMOPHub Concepts Result}
\usage{
new_omophub_concepts(data, meta = list())
}
\arguments{
\item{data}{Concept data (list or tibble).}

\item{meta}{Pagination metadata.}
}
\value{
An \code{omophub_concepts} S3 object.
}
\description{
Creates an S3 object for concept search results.
}
\keyword{internal}
